privacyIDEA Extension
=====================

This is an Authentication Extension, which allows you to authenticate
with a second factor if possession against privacyIDEA.

`privacyIDEA`_ is a system to manage authentication devices like OTP-Tokens,
Yubikeys, Google Authenticator, FreeOTP, One Time Passwords via Email and via
SMS and many more.

The great thing about privacyIDEA is, that you do not need to trust a service
provider,
since you can run your own privacyIDEA installation in your network or
datacenter. Your server, your keys, your data and your control.

You can setup one privacyIDEA system to manage all authentication devices of
all your users and customers. Several TYPO3 installations can authenticate
against this centrally manages privacyIDEA installation under your control.

.. _privacyIDEA: https://privacyidea.org
